@@ -225,8 +225,6 @@ class SPNEGO:
 								return None, False, None
 							if str(response['mechTypes'][0]) == '1.2.840.48018.1.2.2':
 								response['mechToken'] = KRB5Token(result).to_bytes()
-								
-								#response['mechToken'] = bytes.fromhex('2a864886f712010202') +  #???????
 							else:
 								raise Exception('NTLM as RPC GSSAPI not implemented!')
 					
@@ -260,6 +258,8 @@ class SPNEGO:
 				#everything is netotiated, but authentication needs more setps
 				neg_token_raw = NegotiationToken.load(token)
 				neg_token = neg_token_raw.native
+				if neg_token['negState'] == 'accept-completed':
+					return None, True, None
 				response, to_continue, err = await self.process_ctx_authenticate(neg_token['responseToken'], flags = flags, seq_number = seq_number, is_rpc = is_rpc)
 				if err is not None:
 					return None, None, err
