@@ -18,8 +18,8 @@ class DCERPCSMBTransport:
 
 		unc_path = '\\\\%s\\%s%s' % (self.target.smb_connection.target.get_hostname_or_ip(), 'IPC$', self.target.pipe)
 		self.smbfile = SMBFile.from_uncpath(unc_path)
-		await self.smbfile.open(self.target.smb_connection, 'wp')
-		return True, None
+		_, err = await self.smbfile.open(self.target.smb_connection, 'wp')
+		return True, err
 
 	@red
 	async def disconnect(self):
@@ -27,24 +27,31 @@ class DCERPCSMBTransport:
 	
 	@red
 	async def send(self, data, forceWriteAndx = 0, forceRecv = 0):
-		if self._max_send_frag:
-			offset = 0
-			while 1:
-				toSend = data[offset:offset+self._max_send_frag]
-				if not toSend:
-					break
-				await self.smbfile.write(toSend)
-				offset += len(toSend)
-				
-		else:
-			await self.smbfile.write(data)
-		
-		return True, None
+		try:
+			if self._max_send_frag:
+				offset = 0
+				while 1:
+					toSend = data[offset:offset+self._max_send_frag]
+					if not toSend:
+						break
+					total_writen, err = await self.smbfile.write(toSend)
+					if err is not None:
+						raise err
+					offset += len(toSend)
+					
+			else:
+				total_writen, err = await self.smbfile.write(data)
+				if err is not None:
+					raise err
+			
+			return True, None
+		except Exception as e:
+			return None, e
 
 	
 	@red
 	async def recv(self, count): #async def recv(self, forceRecv = 0, count = 0):
 		#print(count)
-		data = await self.smbfile.read(count)
+		data, err = await self.smbfile.read(count)
 		#print('recv %s' % repr(data))
-		return data, None
\ No newline at end of file
+		return data, err
\ No newline at end of file
