@@ -54,12 +54,14 @@ class TCPSocket:
 				try:
 					data = await self.reader.read(10240)
 					await self.in_queue.put( (data, None) )
+					if data == b'':
+						return
 				
 				except asyncio.CancelledError as e:
 					lasterror = e
 					break
 				except Exception as e:
-					logger.exception('[TCPSocket] handle_incoming %s' % str(e))
+					logger.debug('[TCPSocket] handle_incoming %s' % str(e))
 					lasterror = e
 					break
 			
@@ -108,11 +110,11 @@ class TCPSocket:
 				self.reader, self.writer = await asyncio.wait_for(con, int(self.settings.timeout))
 			except asyncio.TimeoutError:
 				logger.debug('[TCPSocket] Connection timeout')
-				raise SMBConnectionTimeoutException()
+				raise SMBConnectionTimeoutException('[TCPSocket] Connection timeout')
 				
 			except ConnectionRefusedError:
 				logger.debug('[TCPSocket] Connection refused')
-				raise SMBConnectionRefusedException()
+				raise SMBConnectionRefusedException('[TCPSocket] Connection refused')
 				
 			except asyncio.CancelledError:
 				#the SMB connection is terminating
